# mjcf2urdf

Convert MuJoCo mjcf to URDF format.

## Installation

```
pip install mjcf2urdf
```

## How to Use

```
mjcf2urdf <INPUT_MCJF_FILE> --out <OUTPUT_DIRECTORY>
```

```--out``` is optional. If not specified this value, `result` directory created.
